#include "Text.h"

namespace Text
{
    //Declare externs
    SDL_Surface* surf;
    SDL_Color color;
    std::map<int, TTF_Font*> mFonts;

    //Necessary for itoa conversion of ints
    char buffer[33];

    void Init()
    {
        //Inits TTF and tells program to Quit TTF at exit
        TTF_Init();
        atexit(TTF_Quit);

        //Stores various font sizes in mFonts
        for(int x = 0; x<=14; x++)
        {
            mFonts[x] = TTF_OpenFont("Fonts/IMPACT.TTF", x);
        }
        for(int x = 16; x<=36; x+=2)
        {
            mFonts[x] = TTF_OpenFont("Fonts/IMPACT.TTF", x);
        }

        //If you want another size not supported then use...
        //mFonts[sizeyouwant] = TTF_OpenFont("fontfilename, sizeyouwant);

        surf = NULL;
    }

    //SDL_Colors are weird, so I had to use something like this to change the color on the fly
    void SetColor(int r, int g, int b, int a)
    {
        color.r = r;
        color.g = g;
        color.b = b;
        color.unused = a;
    }

    SDL_Rect GetSize(std::string text, int size, int num)
    {
        SDL_FreeSurface(surf);

        SDL_Rect rect;

        //Checks if number data was added and appends to string if so
        if(num != -3)
        {
            std::string total = text + itoa(num, buffer, 10);

            surf = TTF_RenderText_Blended(mFonts[size], total.c_str(), color);
        }
        else
        {
            surf = TTF_RenderText_Blended(mFonts[size], text.c_str(), color);
        }

        //We don't really care about the x and y, only the w and h are important
        rect.x = 0;
        rect.y = 0;
        rect.w = surf->w;
        rect.h = surf->h;

        return rect;
    }

    void Draw(std::string text, int size, int x, int y, ColorName clr)
    {
        SDL_FreeSurface(surf);

        switch(clr)
        {
            case BLACK: SetColor(0, 0, 0, 0); break;
            case WHITE: SetColor(255, 255, 255, 0); break;
            case RED: SetColor(255, 0, 0, 0); break;
            case GREEN: SetColor(0, 255, 0, 0); break;
            case BLUE: SetColor(0, 0, 255, 0); break;

            default: break;
        }

        surf = TTF_RenderText_Blended(mFonts[size], text.c_str(), color);

        Graphics::DrawImage(surf, x, y);
    }

    void Draw(std::string text, int size, int x, int y, int r, int g, int b, int a)
    {
        SDL_FreeSurface(surf);

        SetColor(r, g, b, a);

        surf = TTF_RenderText_Blended(mFonts[size], text.c_str(), color);

        Graphics::DrawImage(surf, x, y);
    }

    void Draw(int text, int size, int x, int y, ColorName clr)
    {
        SDL_FreeSurface(surf);

        switch(clr)
        {
            case BLACK: SetColor(0, 0, 0, 0); break;
            case WHITE: SetColor(255, 255, 255, 0); break;
            case RED: SetColor(255, 0, 0, 0); break;
            case GREEN: SetColor(0, 255, 0, 0); break;
            case BLUE: SetColor(0, 0, 255, 0); break;

            default: break;
        }

        surf = TTF_RenderText_Blended(mFonts[size], itoa(text, buffer, 10), color);

        Graphics::DrawImage(surf, x, y);
    }

    void Draw(int text, int size, int x, int y, int r, int g, int b, int a)
    {
        SDL_FreeSurface(surf);

        SetColor(r, g, b, a);

        surf = TTF_RenderText_Blended(mFonts[size], itoa(text, buffer, 10), color);

        Graphics::DrawImage(surf, x, y);
    }

    void Quit()
    {
        SDL_FreeSurface(surf);

        for(int x = 0; x<=14; x++)
        {
            TTF_CloseFont(mFonts[x]);
        }
        for(int x = 16; x<=36; x+=2)
        {
            TTF_CloseFont(mFonts[x]);
        }
    }
}
