#ifndef TEXT_H_INCLUDED
#define TEXT_H_INCLUDED

#include <SDL_TTF.h>
#include <map>

#include "Graphics.h"
#include <string>

/////////////////////////////////////////////////////////////////////////
//Namespace Text
/////////////////////////////////////////////////////////////////////////
//Used for drawing text on the screen
//Allows for different fonts, sizes, and colors
/////////////////////////////////////////////////////////////////////////

namespace Text
{
    ////////Enums////////

    //Used to identify the color to draw with
    enum ColorName
    {
        BLACK,
        WHITE,
        RED,
        GREEN,
        BLUE
    };


    ////////Functions////////

    //Initializes SDL_TTF and the Text namespace
    void Init();

    //Sets member color equal to the rgba value passed
    void SetColor(int, int, int, int);

    //Returns a rect containing the width and height of the ttf surface containing the given data (x and y = 0)
    SDL_Rect GetSize(std::string, int, int num = -3);

    //Draws given text of given size at given x and y using given color, specified by ColorName
    void Draw(std::string, int, int, int, ColorName);

    //Draws given text of given size at given x and y using given rgba value
    void Draw(std::string, int, int, int, int, int, int, int);

    //Draws given number of given size at given x and y using given color, specified by ColorName
    void Draw(int, int, int, int, ColorName);

    //Draws given number of given size at given x and y using given rgba value
    void Draw(int, int, int, int, int, int, int, int);

    //Frees memory, called at program exit
    void Quit();


    ////////Member Variables////////

    //Contains the generated surface with the text on it
    extern SDL_Surface *surf;

    //Changes as the user specifies, stores the current color being drawn with
    extern SDL_Color color;

    //Filled with different font sizes on Init
    extern std::map<int, TTF_Font*> mFonts;
};

#endif  //TEXT_H_INCLUDED
